@@ -22,8 +22,8 @@ function (loop.data, bn.data) {
 
 p_fdh_line <-
 function (scope, peers, flip.x, flip.y) {
-  x.points <- c()
-  y.points <- c()
+  x.points <- NULL
+  y.points <- NULL
 
   y.old <- scope[3 + flip.y]
   for (i in 1:nrow(peers)) {
@@ -37,4 +37,4 @@ function (scope, peers, flip.x, flip.y) {
   x.points <- c(x.points, scope[2 - flip.x])
   y.points <- c(y.points, y.new)
   return (list(x.points, y.points))
-}
\ No newline at end of file
+}
